@@ -55,7 +55,7 @@ class POLWeb(threading.Thread):
 			fichier_online="version_mac"
 		else:
 			fichier_online="version2"
-		return os.popen('wget -q "$SITE/'+fichier_online+'.php?v=$VERSION" -T 10 -O-','r').read()
+		return os.popen('wget -4 -q "'+os.environ["SITE"]+'/'+fichier_online+'.php?v='+os.environ["VERSION"]+'" -T 30 -O-','r').read()
 	
 	def real_check(self):
 		self.WebVersion = self.LastVersion()
@@ -88,19 +88,50 @@ class POLWeb(threading.Thread):
 		    
 class MainWindow(wx.Frame):
   def __init__(self,parent,id,title):
-	wx.Frame.__init__(self, parent, 1000, title, size = (430, 430))
+			
+	wx.Frame.__init__(self, parent, 1000, title, size = (515,450))
+	self.SetMinSize((300,300))
 
+	try:
+		self.windowWidth = int(playonlinux.GetSettings("MAINWINDOW_WIDTH"))
+		self.windowHeight = int(playonlinux.GetSettings("MAINWINDOW_HEIGHT"))
+		self.SetSize((self.windowWidth,self.windowHeight))
+	except:
+		self.windowWidth = 450
+		self.windowHeight = 450
 		
+	try:
+		self.windowx = int(playonlinux.GetSettings("MAINWINDOW_X"))
+		self.windowy = int(playonlinux.GetSettings("MAINWINDOW_Y"))
+		self.screen_width = wx.Display().GetGeometry()[2]
+		self.screen_height = wx.Display().GetGeometry()[3]
+		
+		if(self.screen_width >= self.windowx and self.screen_height >= self.windowy):
+			self.SetPosition((self.windowx, self.windowy))
+		else:
+			self.Center(wx.BOTH)
+	except:
+		self.Center(wx.BOTH)
+				
 	self.SetIcon(wx.Icon(Variables.playonlinux_env+"/etc/playonlinux.png", wx.BITMAP_TYPE_ANY))
 	self.timer = wx.Timer(self, 1)
-	self.images = wx.ImageList(32, 32)
-
+	
+	try:
+		self.iconSize = int(playonlinux.GetSettings("ICON_SIZE"))
+	except:
+		self.iconSize = 32
+	
+		
+	self.images = wx.ImageList(self.iconSize, self.iconSize)
+	self.imagesEmpty = wx.ImageList(1,1)
+	
 	self.updater = POLWeb()
 	self.updater.start()
 	self.sendAlertStr = None
 	
 	self.list_game = wx.TreeCtrl(self, 105, style=wx.TR_HIDE_ROOT|wx.TR_FULL_ROW_HIGHLIGHT)	
 	self.list_game.SetSpacing(0);
+	self.list_game.SetIndent(5);
 	self.list_game.SetImageList(self.images)
 
 	
@@ -115,6 +146,21 @@ class MainWindow(wx.Frame):
 	self.filemenu.Append(216, _("Donate"))
 	self.filemenu.Append(wx.ID_EXIT, _("Exit"))
 
+	self.displaymenu = wx.Menu()
+	self.icon16 = self.displaymenu.AppendRadioItem(501, _("Small icons"))
+	self.icon24 = self.displaymenu.AppendRadioItem(502, _("Medium icons"))
+	self.icon32 = self.displaymenu.AppendRadioItem(503, _("Large icons"))
+	self.icon48 = self.displaymenu.AppendRadioItem(504, _("Very large icons"))
+	
+	if(self.iconSize == 16):
+		self.icon16.Check(True)
+	if(self.iconSize == 24):
+		self.icon24.Check(True)
+	if(self.iconSize == 32):
+		self.icon32.Check(True)
+	if(self.iconSize == 48):
+		self.icon48.Check(True)
+		
 	self.expertmenu = wx.Menu()
 
 	self.winever_item = wx.MenuItem(self.expertmenu, 107, _("Manage Wine versions"))
@@ -234,6 +280,7 @@ class MainWindow(wx.Frame):
 
 	self.menubar = wx.MenuBar()
 	self.menubar.Append(self.filemenu, _("File"))
+	self.menubar.Append(self.displaymenu, _("Display"))
 	self.menubar.Append(self.expertmenu, _("Tools"))
 	self.menubar.Append(self.optionmenu, _("Settings"))
 	self.menubar.Append(self.pluginsmenu, _("Plugins"))
@@ -265,7 +312,12 @@ class MainWindow(wx.Frame):
 	wx.EVT_MENU(self,  wx.ID_EXIT,  self.ClosePol)
 	wx.EVT_MENU(self,  wx.ID_DELETE,  self.UninstallGame)
 	
-
+	# Display
+	wx.EVT_MENU(self, 501,  self.iconDisplay)
+	wx.EVT_MENU(self, 502,  self.iconDisplay)
+	wx.EVT_MENU(self, 503,  self.iconDisplay)
+	wx.EVT_MENU(self, 504,  self.iconDisplay)
+	
 	# Expert
 	wx.EVT_MENU(self, 101,  self.Reload)
 	wx.EVT_MENU(self, 107,  self.WineVersion)
@@ -309,7 +361,7 @@ class MainWindow(wx.Frame):
 	wx.EVT_MENU(self, 234, self.UninstallGame)
 	wx.EVT_MENU(self, 235, self.RKill)
 	#self.sb.Hide()
-	
+
   def StatusRead(self):
 	self.sb.SetStatusText(self.updater.sendToStatusBarStr, 0)
 	if(self.updater.Gauge == True):
@@ -375,7 +427,28 @@ class MainWindow(wx.Frame):
 		os.system("bash \""+Variables.playonlinux_rep+"/plugins/"+plugin+"/scripts/menu\" \""+game_exec+"\"&")
 	except : 
 		pass
+
+  def iconDisplay(self, event):
+	iconEvent=event.GetId()
+	
+	if(iconEvent == 501):
+		self.iconSize = 16
+	if(iconEvent == 502):
+		self.iconSize = 24
+	if(iconEvent == 503):
+		self.iconSize = 32
+	if(iconEvent == 504):
+		self.iconSize = 48
 		
+	playonlinux.SetSettings("ICON_SIZE",str(self.iconSize))		
+	self.list_game.SetImageList(self.imagesEmpty)
+	self.images.Destroy()
+	self.images = wx.ImageList(self.iconSize, self.iconSize)
+	self.list_game.SetImageList(self.images)
+
+		
+	self.Reload(self)
+								
   def OpenIrc(self, event):
 	self.irc = ircgui.IrcClient(self)
 	self.irc.Center(wx.BOTH)
@@ -430,14 +503,21 @@ class MainWindow(wx.Frame):
 	 self.images.RemoveAll()
 	 root = self.list_game.AddRoot("")
 	 self.i = 0
+	 if(self.iconSize <= 32):
+		self.iconFolder = "32";
+	 else:
+		self.iconFolder = "full_size";
 	 for game in self.games: #METTRE EN 32x32
-		if(os.path.exists(Variables.playonlinux_rep+"/icones/32/"+game)):
-			file_icone = Variables.playonlinux_rep+"/icones/32/"+game
+		if(os.path.exists(Variables.playonlinux_rep+"/icones/"+self.iconFolder+"/"+game)):
+			file_icone = Variables.playonlinux_rep+"/icones/"+self.iconFolder+"/"+game
 		else:
-			file_icone = Variables.playonlinux_env+"/etc/playonlinux32.png"
+			file_icone = Variables.playonlinux_env+"/etc/playonlinux.png"
 
 		try:
-			self.images.Add(wx.Bitmap(file_icone))
+			self.bitmap = wx.Image(file_icone)
+			self.bitmap.Rescale(self.iconSize,self.iconSize,wx.IMAGE_QUALITY_HIGH)
+			self.bitmap = self.bitmap.ConvertToBitmap()
+			self.images.Add(self.bitmap)
 		except:
 			pass
 		item = self.list_game.AppendItem(root, game, self.i)
@@ -499,6 +579,7 @@ class MainWindow(wx.Frame):
 
 
   def AutoReload(self, event):
+	
 	self.StatusRead()
 	fichier_index = os.environ["REPERTOIRE"]+"/configurations/guis/index_"+os.environ["POL_ID"]
 	#print(fichier_index)
@@ -547,6 +628,13 @@ class MainWindow(wx.Frame):
   def ClosePol(self, event):
     if(wx.YES == wx.MessageBox(_('Are you sure you want to close all {0} Windows?').format(os.environ["APPLICATION_TITLE"]).decode("utf-8"), style=wx.YES_NO | wx.ICON_QUESTION)):
 		os.remove(Variables.playonlinux_rep+"/configurations/guis/index_"+os.environ["POL_ID"])
+		self.SizeToSave = self.GetSize();
+		self.PositionToSave = self.GetPosition();
+		# Save size and position
+		playonlinux.SetSettings("MAINWINDOW_WIDTH",str(self.SizeToSave[0]))
+		playonlinux.SetSettings("MAINWINDOW_HEIGHT",str(self.SizeToSave[1]-Variables.windows_add_playonmac*56))
+		playonlinux.SetSettings("MAINWINDOW_X",str(self.PositionToSave[0]))
+		playonlinux.SetSettings("MAINWINDOW_Y",str(self.PositionToSave[1]))
 		os._exit(0)
     return None
     
@@ -565,8 +653,8 @@ class MainWindow(wx.Frame):
     self.aboutBox.AddDeveloper(_("Packager: ")+"MulX (Petit Aymeric), Tinou (Pâris Quentin)")
     self.aboutBox.AddDeveloper(_("Icons:")+"Faenza-Icons http://tiheum.deviantart.com/art/Faenza-Icons-173323228")
     self.aboutBox.AddDeveloper(_("The following people contributed to this program: ")+"kiplantt, Salvatos, Minchul")
-    self.aboutBox.AddTranslator(_("Translation made on Launchpad:"))
-    self.aboutBox.AddTranslator("https://translations.launchpad.net/playonlinux/")
+    self.aboutBox.AddTranslator(_("Translations:"))
+    self.aboutBox.AddTranslator(_("Read TRANSLATORS file"))
 
     if(os.environ["POL_OS"] == "Mac"):
     	self.aboutBox.SetWebSite("http://www.playonmac.com")
@@ -600,7 +688,7 @@ class PlayOnLinuxApp(wx.App):
 		#self.icon.SetIcon(wx.Icon(Variables.playonlinux_env+"/etc/playonmac.png", wx.BITMAP_TYPE_ANY))
 		self.frame = MainWindow(None, -1, os.environ["APPLICATION_TITLE"])
 		self.SetTopWindow(self.frame)
-		self.frame.Center(wx.BOTH)
+		#self.frame.Center(wx.BOTH)
 		self.frame.Show(True)
 		
 		return True
